@@ -21,6 +21,7 @@ from logilab.common.fileutils import norm_read
 from logilab.common.textutils import splitstrip
 from logilab.common.decorators import cached
 from logilab.common.compat import any
+from logilab.common.contexts import pushd
 from logilab.common.proc import RESOURCE_LIMIT_EXCEPTION
 
 try:
@@ -132,8 +133,6 @@ class PyTestParser(SimpleOutputParser):
         self.failures = 0
         self.skipped  = 0
         self.errors   = 0
-        #self.success is dynamiclty computed
-        #self.status = SUCCESS
 
     def _parse(self, stream):
         self.status = None
@@ -238,13 +237,13 @@ class PyTestChecker(BaseChecker):
         else:
             pyversions = None
         if pyversions:
-            pyversions = ['python%s' % pyver for pyver in pyversions]
-            pyversions_ = [python for python in pyversions
-                           if pyversion_available(python)]
-            if len(pyversions) > len(pyversions_):
-                for pyver in pyversions:
-                    if not pyver in pyversions:
-                        self.writer.error('config asked for %s, but it\'s not available', pyver)
+            pyversions_ = []
+            for pyver in pyversions:
+                python = 'python%s' % pyver
+                if not pyversion_available(python):
+                    self.writer.error('config asked for %s, but it\'s not available', pyver)
+                else:
+                    pyversions_.append(python)
             pyversions = pyversions_
         else:
             pyversions = [sys.executable]
@@ -390,17 +389,10 @@ class PyUnitTestChecker(PyTestChecker):
             if exists(testdir):
                 self._path = testdir
                 if self._coverage is not None:
-                    self._coverage.coverage_data_dir = pyinstall_path(test)
-                # FIXME keep compatibility with python2.4 in Debian stable (etch)
-                # FIXME Feel free to use the 'with' statement afterwards.
-                #with pushd(testdir):
-                cwd = os.getcwd()
-                os.chdir(testdir)
-                try:
+                    self._coverage.coverage_data_dir = testdir
+                with pushd(testdir):
                     _status = self.run_tests()
                     status = self.merge_status(status, _status)
-                finally:
-                    os.chdir(cwd)
                 break
         else:
             self.writer.error('no test directory', path=basepath)
@@ -657,19 +649,12 @@ class PyCoverageChecker(BaseChecker):
             if not self.coverage_data_dir:
                 self.writer.error('no coverage information generated')
                 return NODATA
-            # FIXME keep compatibility with python2.4 in Debian stable (etch)
-            # FIXME Feel free to use the 'with' statement afterwards.
-            #with pushd(testdir):
-            cwd = os.getcwd()
-            os.chdir(self.coverage_data_dir)
-            try:
+            with pushd(self.coverage_data_dir):
                 if not exists('.coverage'):
                     self.writer.fatal('no coverage information',
                                       path=self.coverage_data_dir)
                     return NODATA
                 percent = self._get_cover_info(pyinstall_path(test))
-            finally:
-                os.chdir(cwd)
         if percent < self.threshold:
             return FAILURE
         return SUCCESS
