@@ -1,7 +1,7 @@
 """installation preprocessor using distutils setup.py
 
 :organization: Logilab
-:copyright: 2003-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 :license: General Public License version 2 - http://www.gnu.org/licenses
 """
@@ -13,6 +13,7 @@ import shutil
 from os.path import join, exists, abspath
 
 from logilab.common import optik_ext as opt
+from logilab.common.contexts import pushd
 
 from apycotbot import register, SetupException
 from apycotbot.utils import EnvironmentTrackerMixin, Command
@@ -86,23 +87,15 @@ class DistutilsProcessor(EnvironmentTrackerMixin, BasePreProcessor):#SetPythonEn
         if not exists(join(path, 'setup.py')):
             raise SetupException('No file %s' % abspath(join(path, 'setup.py')))
         self._installed.add(path)
-        # FIXME keep compatibility with python2.4 in Debian stable (etch)
-        # FIXME Feel free to use the 'with' statement afterwards.
-        #with pushd(path):
-        cwd = os.getcwd()
-        os.chdir(path)
-        
         cmd_args = ['python', 'setup.py', 'install', '--home',
-                           join(test.tmpdir, 'local')]
+                    join(test.tmpdir, 'local')]
         if opt.check_yn(None, 'quiet', self.get_option('quiet')):
             cmd_args.append('--quiet')
-        try:
+        with pushd(path):
             cmd = Command(self.writer, cmd_args, raises=True)
             cmd.run()
             if exists('build'):
                 shutil.rmtree('build') # remove the build directory
-        finally:
-            os.chdir(cwd)
 
 
 register('preprocessor', DistutilsProcessor)
