@@ -293,7 +293,7 @@ the daemon rather than the user running the command',
             msg = msg + ' for branch %s'
             args += (branch,)
         self.info(msg, *args)
-        from_inst_id = tconfig.metainformation()['source']['uri']
+        from_inst_id = tconfig.cw_metainformation()['source']['uri']
         if from_inst_id == 'system':
             from_inst_id = cnxh.cwqinstid
         else:
