@@ -23,6 +23,7 @@ from logilab.common.proc import (RESOURCE_LIMIT_EXCEPTION,
                                  ResourceError, ResourceController)
 from logilab.common.tasksqueue import LOW, Task
 from logilab.common.configuration import format_option_value
+from logilab.common.contexts import pushd
 
 from apycotbot import SetupException, ConfigError, get_registered
 from apycotbot.utils import (SUCCESS, SKIPPED, FAILURE, ERROR, KILLED,
@@ -388,11 +389,8 @@ class Test(EnvironmentTrackerMixin):
         """setup, run and clean the test"""
         # FIXME keep compatibility with python2.4 in Debian stable (etch)
         # FIXME Feel free to use the 'with' statement afterwards.
-        #with pushd(self.tmpdir):
-        cwd = os.getcwd()
-        os.chdir(self.tmpdir)
         status = FAILURE
-        try:
+        with pushd(self.tmpdir):
             try:
                 self.writer.start_test(self.apycot_repository().branch)
                 if self.keep_test_dir:
@@ -421,5 +419,3 @@ class Test(EnvironmentTrackerMixin):
                     # XXX log error
                     pass
                 self._cnx.close()
-        finally:
-            os.chdir(cwd)
