@@ -29,7 +29,7 @@ http://www.logilab.fr/ -- mailto:contact@logilab.fr'''
 author = "David Pierre-Yves"
 author_email = "pierre-yves.david@logilab.fr"
 
-short_desc = "a good package compatible with python2.4 and above"
+description = "a good package compatible with python2.4 and above"
 long_desc = "a good package compatible with python2.4 and above"
 
 
