@@ -128,8 +128,8 @@ class DataWriter(object):
             'CheckResult', name=self._unicode(name), status=u'processing',
             starttime=datetime.now(),
             during_execution=self._cnxh.cw.entity_from_eid(self._ex_eid)).eid
-        for name, value in options.iteritems():
-            self.raw(name, value, 'option', commit=False)
+        optionsstr = '\n'.join('%s=%s' % (k, v) for k, v in options.iteritems())
+        self.info(optionsstr)
         self._cnxh.commit()
         self._log_stack.append([])
 
